1.0.0 (2022-04-19)
------------------

General
^^^^^^^

- The minimum required Python version is 3.8. [#11]

- The minimum required Numpy version is 1.18. [#11]

- The minimum required Scipy version is 1.6.0. [#11]

- The minimum required Astropy version is 4.1. [#11]


0.1.1 (2016.08.16)
------------------

- Initial release.
